from flask import Flask, request, Response
import json
import logic
from facebookApiSupporter import process_response

app = Flask(__name__)


@app.post("/handle-message")
def handle_message():
    content_type = request.headers.get('Content-Type')
    if (content_type != 'application/json'):
        return 'Content-Type not supported!'

    data = request.json
    receivedMessage = data["receivedMessage"]
    input_message = json.loads(receivedMessage)['text']
    senderPsid = data["senderPsid"]

    response = logic.handle_message(senderPsid, input_message)
    process_response(senderPsid, response["type"], response["payload"])
    return Response("success", status=201, mimetype='application/json')


@app.post("/handle-post-back")
def handle_post_back():
    content_type = request.headers.get('Content-Type')
    if (content_type != 'application/json'):
        return 'Content-Type not supported!'

    data = request.json
    payload = data["payload"]
    senderPsid = data["senderPsid"]

    response = logic.handle_post_back(senderPsid, payload)
    process_response(senderPsid, response["type"], response["payload"])
    return Response("success", status=201, mimetype='application/json')


if __name__ == '__main__':
    app.run(debug=True, port=8001)



import requests
from xClassService import getPageAccessToken


def call_send_api(senderPsid, response):
    url = "https://graph.facebook.com/v16.0/me/messages"
    params = {'access_token': getPageAccessToken()}
    print("param", params)
    headers = {'Content-Type': 'application/json'}
    data = {
        'recipient': {'id': senderPsid},
        'message': response
    }
    response = requests.post(url, params=params, headers=headers,
                             json=data)
    print("response", response.json())
    return response


def message(text):
    return {
        'text': text
    }


def post_back(postBackObject):
    postBack = {
        attachment: {
            type: "template",
            payload: {
                template_type: "generic",
                elements: [
                    {
                        title: postBackObject["title"],
                        subtitle: postBackObject["subtitle"],
                        buttons: map(lambda x: {
                            type: "postback",
                            title: x.title,
                            payload: x.payload
                        }, postBackObject.buttons)
                    }
                ]
            }
        }
    }
    return postBack


def quick_reply(quickReplyObject):
    quickReply = {
        text: quickReplyObject.text,
        quick_replies: map(lambda x: {
            title: x.title,
            payload: x.payload,
            content_type: text
        }, quickReplyObject.quick_replies)
    }
    return quick_reply

def process_response(senderPsid, responseType, payload):
    if responseType == "message":
        return call_send_api(senderPsid, message(payload))
    elif responseType == "post_back":
        return call_send_api(senderPsid, post_back(payload))
    elif responseType == "quick_reply":
        return call_send_api(senderPsid, quick_reply(payload))
    else:
        return "Unknown response type"



from logic import PAGE_ID, API_KEY
import requests


def getPageAccessToken():
    url = f"https://2c1fsxykqc.execute-api.ap-southeast-1.amazonaws.com/chat-bot-mapping/get-page-token-by-page-id"
    params = {'pageId': PAGE_ID}
    headers = {'api-key': API_KEY}
    response = requests.get(url, params=params, headers=headers)
    print("response", response.json())
    return response.json()['data']["pageAccessToken"]



from facebookApiSupporter import call_send_api, message, post_back, quick_reply
import json


def handle_message(senderPsid, receivedMessage):
    print("receivedMessage", receivedMessage)
    input_message = json.loads(receivedMessage)['text']
    print("input_message", input_message)
    return {
        "type": "message",
        "payload": f"You have sent the message {input_message}"
    }


def handle_post_back(senderPsid, payload):
    return {
        "type": "message",
        "payload": f"You have trigger the post back type {payload}"
    }



import shutil
import os

def find_package_folder():
    # Get the path of the current script
    current_script_path = os.path.abspath(__file__)

    # Navigate to the parent directory (assuming your package folder is in the same directory as this script)
    package_folder_path = os.path.dirname(current_script_path)

    return package_folder_path

def copy_folder(source_folder, destination_folder):
    try:
        # Copy the entire contents of the source folder to the destination folder
        shutil.copytree(source_folder, destination_folder)
        print("Folder copied successfully!")
    except Exception as e:
        print(f"An error occurred: {e}")


def copy_file(source_file, destination_file):
    try:
        shutil.copy(source_file, destination_file)
        print(
            f"File '{source_file}' copied to '{destination_file}' successfully.")
    except IOError as e:
        print(f"Unable to copy file. {e}")


def change_file_content(file_path, new_content):
    try:
        # Open the file in write mode
        with open(file_path, 'w') as file:
            # Write the new content to the file
            file.write(new_content)
        print("File content changed successfully!")
    except Exception as e:
        print(f"An error occurred: {e}")


class ChatBotFbApp:
    def __init__(self, isProd=True):
        self.isProd = isProd

    def build(self, filePath, destination_folder):
        absPath = os.path.abspath(filePath)
        absDestination = os.path.abspath(destination_folder)
        copy_folder(f"{find_package_folder()}/chat_bot_fb", absDestination)
        copy_file(absPath, f"{absDestination}/logic.py")



import pystache

def multipartify(data, parent_key=None, formatter: callable = None) -> dict:
    if formatter is None:
        formatter = lambda v: (None, v)  # Multipart representation of value

    if type(data) is not dict:
        return {parent_key: formatter(data)}

    converted = []

    for key, value in data.items():
        current_key = key if parent_key is None else f"{parent_key}[{key}]"
        if type(value) is dict:
            converted.extend(multipartify(value, current_key, formatter).items())
        elif type(value) is list:
            for ind, list_value in enumerate(value):
                iter_key = f"{current_key}[{ind}]"
                converted.extend(multipartify(list_value, iter_key, formatter).items())
        else:
            converted.append((current_key, formatter(value)))

    return dict(converted)

def render_template(template, data):
    """
    Use pystache to render the Mustache template with input data
    """
    renderer = pystache.Renderer()
    html_output = renderer.render(template, data)
    return html_output

def load_template_from_file(template_file):
    """
    Read the Mustache template from an external file
    """
    with open(template_file, "r", encoding="utf-8") as file:
        template = file.read()
    return template
